==> ckan-2.0.tar.gz: ckan-2.0/ckan/public/base/i18n/ja.js <==
{
  "": {
    "domain": "ckan",
    "lang": "ja",
    "plural-forms": "nplurals=1; plural=0;"
  },
  "An Error Occurred": [
    null,
    "エラーが発生しました"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "このアクションを実行してよろしいですか？"
  ],
  "Cancel": [
    null,
    "キャンセル"
  ],
  "Confirm": [
    null,
    "確認"
  ],
  "Edit": [
    null,
    "編集"
  ],
  "Failed to load data API information": [
    null,
    "データAPIの情報の読み込みに失敗しました"
  ],
  "Follow": [
    null,
    "フォロー"
  ],
  "Hide": [
    null,
    "隠す"
  ],
  "Input is too short, must be at least one character": [
    null,
    "1文字以上入力してください"
  ],
  "Loading...": [
    null,
    "ロード中..."
  ],
  "No matches found": [
    null,
    "見つかりません"
  ],
  "Please Confirm Action": [
    null,
    "アクションを確認してください"
  ],
  "Resource uploaded": [
    null,
    "リソースがアップロードされました"
  ],
  "Show more": [
    null,
    "もっとみる"
  ],
  "Start typing…": [
    null,
    "入力開始..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "保存されていない変更があります"
  ],
  "There is no API data to load for this resource": [
    null,
    "このリソースのデータを読み込むためのAPIがありません"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "アップロードを許可できません"
  ],
  "Unable to get data for uploaded file": [
    null,
    "アップロードしたファイルからデータを取得できません"
  ],
  "Unable to upload file": [
    null,
    "ファイルをアップロードできません"
  ],
  "Unfollow": [
    null,
    "フォロー解除"
  ],
  "Upload a file": [
    null,
    "ファイルをアップロード"
  ],
  "show less": [
    null,
    "少なく表示"
  ],
  "show more": [
    null,
    "もっとみる"
  ]
}

==> ckan-2.1.1.tar.gz: ckan-2.1.1/ckan/public/base/i18n/ja.js <==
{
  "": {
    "domain": "ckan",
    "lang": "ja",
    "plural-forms": "nplurals=1; plural=0;"
  },
  "An Error Occurred": [
    null,
    "エラーが発生しました"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "このアクションを実行してよろしいですか？"
  ],
  "Cancel": [
    null,
    "キャンセル"
  ],
  "Confirm": [
    null,
    "確認"
  ],
  "Edit": [
    null,
    "編集"
  ],
  "Failed to load data API information": [
    null,
    "データAPIの情報の読み込みに失敗しました"
  ],
  "Follow": [
    null,
    "フォロー"
  ],
  "Hide": [
    null,
    "隠す"
  ],
  "Input is too short, must be at least one character": [
    null,
    "1文字以上入力してください"
  ],
  "Loading...": [
    null,
    "ロード中..."
  ],
  "No matches found": [
    null,
    "見つかりません"
  ],
  "Please Confirm Action": [
    null,
    "アクションを確認してください"
  ],
  "Resource uploaded": [
    null,
    "リソースがアップロードされました"
  ],
  "Show more": [
    null,
    "もっとみる"
  ],
  "Start typing…": [
    null,
    "入力開始..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "保存されていない変更があります"
  ],
  "There is no API data to load for this resource": [
    null,
    "このリソースのデータを読み込むためのAPIがありません"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "アップロードを許可できません"
  ],
  "Unable to get data for uploaded file": [
    null,
    "アップロードしたファイルからデータを取得できません"
  ],
  "Unable to upload file": [
    null,
    "ファイルをアップロードできません"
  ],
  "Unfollow": [
    null,
    "フォロー解除"
  ],
  "Upload a file": [
    null,
    "ファイルをアップロード"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "ファイルをアップロードしています。ナビゲートを離れてこのアップロードを終了しても良いですか?"
  ],
  "show less": [
    null,
    "少なく表示"
  ],
  "show more": [
    null,
    "もっとみる"
  ]
}
